@@ -5,7 +5,7 @@ from django.views.generic import TemplateView
 from django_otp.decorators import otp_required
 from two_factor.views.utils import class_view_decorator
 
-from rocky.katalogus import get_katalogus
+from katalogus.client import get_katalogus
 from tools.view_helpers import Breadcrumb, ObjectsBreadcrumbsMixin
 
 logger = getLogger(__name__)
